from core.routes import (connector_callback,
                         connector_command,
                         connector_message,)
from project.views import *


# Mapping handlers and views for Telegram Bot commands.
COMMANDS: list = [
]


MESSAGES: list = [
]


CALLBACKS: list = [
]
